==> microsoft-graph-beta-6.37.0-sources.jar: com/microsoft/graph/beta/models/security/ServiceSource.java <==
package com.microsoft.graph.beta.models.security;

import com.microsoft.kiota.serialization.ValuedEnum;
import java.util.Objects;

@jakarta.annotation.Generated("com.microsoft.kiota")
public enum ServiceSource implements ValuedEnum {
    Unknown("unknown"),
    MicrosoftDefenderForEndpoint("microsoftDefenderForEndpoint"),
    MicrosoftDefenderForIdentity("microsoftDefenderForIdentity"),
    MicrosoftDefenderForCloudApps("microsoftDefenderForCloudApps"),
    MicrosoftDefenderForOffice365("microsoftDefenderForOffice365"),
    Microsoft365Defender("microsoft365Defender"),
    AzureAdIdentityProtection("azureAdIdentityProtection"),
    MicrosoftAppGovernance("microsoftAppGovernance"),
    DataLossPrevention("dataLossPrevention"),
    UnknownFutureValue("unknownFutureValue"),
    MicrosoftDefenderForCloud("microsoftDefenderForCloud"),
    MicrosoftSentinel("microsoftSentinel"),
    MicrosoftInsiderRiskManagement("microsoftInsiderRiskManagement");
    public final String value;
    ServiceSource(final String value) {
        this.value = value;
    }
    @jakarta.annotation.Nonnull
    public String getValue() { return this.value; }
    @jakarta.annotation.Nullable
    public static ServiceSource forValue(@jakarta.annotation.Nonnull final String searchValue) {
        Objects.requireNonNull(searchValue);
        switch(searchValue) {
            case "unknown": return Unknown;
            case "microsoftDefenderForEndpoint": return MicrosoftDefenderForEndpoint;
            case "microsoftDefenderForIdentity": return MicrosoftDefenderForIdentity;
            case "microsoftDefenderForCloudApps": return MicrosoftDefenderForCloudApps;
            case "microsoftDefenderForOffice365": return MicrosoftDefenderForOffice365;
            case "microsoft365Defender": return Microsoft365Defender;
            case "azureAdIdentityProtection": return AzureAdIdentityProtection;
            case "microsoftAppGovernance": return MicrosoftAppGovernance;
            case "dataLossPrevention": return DataLossPrevention;
            case "unknownFutureValue": return UnknownFutureValue;
            case "microsoftDefenderForCloud": return MicrosoftDefenderForCloud;
            case "microsoftSentinel": return MicrosoftSentinel;
            case "microsoftInsiderRiskManagement": return MicrosoftInsiderRiskManagement;
            default: return null;
        }
    }
}

==> microsoft-graph-beta-6.47.0-sources.jar: com/microsoft/graph/beta/models/security/ServiceSource.java <==
package com.microsoft.graph.beta.models.security;

import com.microsoft.kiota.serialization.ValuedEnum;
import java.util.Objects;

@jakarta.annotation.Generated("com.microsoft.kiota")
public enum ServiceSource implements ValuedEnum {
    Unknown("unknown"),
    MicrosoftDefenderForEndpoint("microsoftDefenderForEndpoint"),
    MicrosoftDefenderForIdentity("microsoftDefenderForIdentity"),
    MicrosoftDefenderForCloudApps("microsoftDefenderForCloudApps"),
    MicrosoftDefenderForOffice365("microsoftDefenderForOffice365"),
    Microsoft365Defender("microsoft365Defender"),
    AzureAdIdentityProtection("azureAdIdentityProtection"),
    MicrosoftAppGovernance("microsoftAppGovernance"),
    DataLossPrevention("dataLossPrevention"),
    UnknownFutureValue("unknownFutureValue"),
    MicrosoftDefenderForCloud("microsoftDefenderForCloud"),
    MicrosoftSentinel("microsoftSentinel"),
    MicrosoftInsiderRiskManagement("microsoftInsiderRiskManagement"),
    MicrosoftThreatIntelligence("microsoftThreatIntelligence");
    public final String value;
    ServiceSource(final String value) {
        this.value = value;
    }
    @jakarta.annotation.Nonnull
    public String getValue() { return this.value; }
    @jakarta.annotation.Nullable
    public static ServiceSource forValue(@jakarta.annotation.Nonnull final String searchValue) {
        Objects.requireNonNull(searchValue);
        switch(searchValue) {
            case "unknown": return Unknown;
            case "microsoftDefenderForEndpoint": return MicrosoftDefenderForEndpoint;
            case "microsoftDefenderForIdentity": return MicrosoftDefenderForIdentity;
            case "microsoftDefenderForCloudApps": return MicrosoftDefenderForCloudApps;
            case "microsoftDefenderForOffice365": return MicrosoftDefenderForOffice365;
            case "microsoft365Defender": return Microsoft365Defender;
            case "azureAdIdentityProtection": return AzureAdIdentityProtection;
            case "microsoftAppGovernance": return MicrosoftAppGovernance;
            case "dataLossPrevention": return DataLossPrevention;
            case "unknownFutureValue": return UnknownFutureValue;
            case "microsoftDefenderForCloud": return MicrosoftDefenderForCloud;
            case "microsoftSentinel": return MicrosoftSentinel;
            case "microsoftInsiderRiskManagement": return MicrosoftInsiderRiskManagement;
            case "microsoftThreatIntelligence": return MicrosoftThreatIntelligence;
            default: return null;
        }
    }
}
